Method: WinWindow#ancestor_root_owner
- Defined in:
- lib/winwindow.rb
#ancestor_root_owner ⇒ Object
Retrieves the owned root window by walking the chain of parent and owner windows returned by GetParent.
456 457 458 459 |
# File 'lib/winwindow.rb', line 456 def ancestor_root_owner ret_hwnd=WinUser.GetAncestor(hwnd, GA_ROOTOWNER) @ancestor_root_owner= ret_hwnd > 0 ? self.class.new(ret_hwnd) : nil end |